@@ -1,4 +1,4 @@
-# Modified: 5 MAR 2015
+# Modified: 1 MAY 2015 SDH
 
 stdVol <-
 function(vol,temp=0,pres=1,rh=1,temp.std=NULL,pres.std=NULL,unit.pres="atm",unit.temp="C") {
@@ -6,7 +6,7 @@ function(vol,temp=0,pres=1,rh=1,temp.std=NULL,pres.std=NULL,unit.pres="atm",unit
   pres<-unitConvert(x=pres,unit=unit.pres,to='atm')
   temp<-unitConvert(x=temp,unit=unit.temp,to='C')
 
-  # Next two lines avoid problems when unit.__ is changed but __.norm isn't
+  # Next two lines avoid problems when unit.__ is changed but __.std isn't
   if(is.null(pres.std)) pres.std<-1.0 else pres.std<-unitConvert(x=pres.std,unit=unit.pres,to='atm')
   if(is.null(temp.std)) temp.std<-0.0 else temp.std<-unitConvert(x=temp.std,unit=unit.temp,to='C')
   
@@ -20,7 +20,7 @@ function(vol,temp=0,pres=1,rh=1,temp.std=NULL,pres.std=NULL,unit.pres="atm",unit
   vol.dry<-vol*(pres - pH2O)/pres.std
 
   # Correct dry volume for temperature
-  vol.norm<-vol.dry*(temp.std + 273.15)/(temp + 273.15)
+  vol.std<-vol.dry*(temp.std + 273.15)/(temp + 273.15)
 
-  return(vol.norm)
+  return(vol.std)
 }
